@@ -15,6 +15,7 @@
 #' safetyGraphics:::getSettingValue(list("measure_values","ALP"),testSettings)
 #' safetyGraphics:::getSettingValue(list("NotASetting"),testSettings) #returns NULL
 #' 
+#' @keywords internal
 
 getSettingValue <- function(key,settings){
   stopifnot(typeof(settings)=="list")
@@ -28,6 +29,9 @@ getSettingValue <- function(key,settings){
     #If there are more keys and the value is a list, iterate
     if(typeof(value)=="list"){
       value<-getSettingValue(key[2:length(key)],value)  
+    #If position is provided and the value is a vector
+    }else if(is.numeric(key[[2]]) & length(value)>=key[[2]] & length(key)==2){ 
+      value<-value[[key[[2]]]]
     }else{
       #If there are more keys, but the value is not a list, return NULL
       value<-NULL
