@@ -17,6 +17,23 @@ test_that("different data types for `key` parameter work as expected",{
   expect_equal(getSettingValue(key=list("measure_values",1),settings=testSettings),"Aminotransferase, alanine (ALT)")
 })
 
+test_that("can get a specific item out of a vector if desired",{
+  filter_vector = list(filters=c("SEX","AGE","RACE"))
+  filter_list = list(filters=list("SEX","AGE","RACE"))
+  expect_equal(getSettingValue(key=list("filters"),settings=filter_vector),c("SEX","AGE","RACE"))
+  expect_equal(getSettingValue(key=list("filters",2),settings=filter_vector),"AGE")
+  expect_null(getSettingValue(key=list("filters",2,"test"),settings=filter_vector))
+  expect_null(getSettingValue(key=list("filters",4),settings=filter_vector))
+  expect_null(getSettingValue(key=list("filters","4"),settings=filter_vector)) 
+  
+  
+  
+  expect_equal(getSettingValue(key=list("filters"),settings=filter_list),list("SEX","AGE","RACE"))
+  expect_equal(getSettingValue(key=list("filters",2),settings=filter_list),"AGE")
+
+  
+})
+
 test_that("returns null if the setting isn't found",{
   expect_null(getSettingValue(key="testKeyandmore",settings=list(testKey="ABC")))
   expect_null(getSettingValue(key=c("a","b","c"),settings=list(testKey="ABC")))
